Functions
=========

.. currentmodule:: crema

Primary Functions
*****************
.. autofunction:: assign_confidence

Parsers
*****************
.. autofunction:: read_crux
.. autofunction:: read_mztab
.. autofunction:: read_txt

Writers
*****************
.. autofunction:: to_txt
